android_rasp_flutter

A Flutter Wrapper for SecureVale Android.

Getting Started

This plugin project is a wrapper for SecureVale android-rasp 0.7.1 plug-in package, a specialized package that includes platform-specific implementation code for Android.

##Ensure you Add this in your proguard roles file -keep class com.yourcompany.your_app_package_name.BuildConfig { *; }

For help knowing about android-rasp, view the online repository, which offers full reference on the Kotlin Internals.